XxKeyboardFilterV1

Struct XxKeyboardFilterV1 

pub struct XxKeyboardFilterV1 { /* private fields */ }
keyboard event filtering functionality

Manages the filtering of key presses.

This interface has no events.

Implementations



impl XxKeyboardFilterV1

pub fn unbind(&self)

Stop intercepting

Unbind the keyboard and stop intercepting events.

Unbinds the bound keyboard and the input method. the compositor must stop redirecting keyboard events. Events that the keyboard_filter client has not yet responded to are treated as if they received the “passthrough” action.

This request takes effect immediately.

pub fn filter(&self, serial: u32, action: FilterAction)

decide the processing of a keyboard event

This request controls the filtering of keyboard input events before reaching the focused surface.

Usage:

While keyboard_filter is intercepting, the compositor must send every intercepted event to its bound wl_keyboard, and hold a copy of it in an internal queue. When the client responds with the .filter request, the compositor either removes the event from the queue (filter_action.consume), or sends the copy to the original wl_keyboard objects (filter_action.passthrough).

The compositor must process .filter the oldest event in the queue before processing more recent ones. For this reason, the client sets the argument “serial” to the serial of the corresponding event it received.

Exceptions:

If the event is other than wl_keyboard.key or contains no serial, it cannot be filtered. The keyboard_filter client must not respond to it with .filter request. When such an event is oldest in the queue, the compositor must proceed as if the event had received a “passthrough” reply.

As of wl_keyboard v10 and keyboard_filter_v1, the only event that can be filtered is the wl_keyboard.key event.

Sequence:

The wl_keyboard begins to receive events after input_method.activate is committed. The valid serial is the serial of the oldest wl_keyboard event which has been sent after input_method.activate but which hasn’t yet received a .filter confirmation. The compositor may raise the invalid_serial error in response to events with serials it had not issued. The compositor must ignore events with all other serials. (Particularly, this means events with repeating serials are accepted normally and are not ignored). Events must be filtered in order of arrival.

pub fn destroy(&self)

destroy the keyboard

Destroys the keyboard_filter object, stops event interception, and unbinds the wl_keyboard and input_method objects bound to it.